Struct IntoIter
struct IntoIter<A: Array> { ... }
An iterator that consumes a SmallVec and yields its items by value.
Returned from SmallVec::into_iter.
Implementations
impl<A: Array> IntoIter<A>
fn as_slice(self: &Self) -> &[<A as >::Item]Returns the remaining items of this iterator as a slice.
fn as_mut_slice(self: &mut Self) -> &mut [<A as >::Item]Returns the remaining items of this iterator as a mutable slice.
impl<A> Freeze for IntoIter<A>
impl<A> RefUnwindSafe for IntoIter<A>
impl<A> Send for IntoIter<A>
impl<A> Sync for IntoIter<A>
impl<A> Unpin for IntoIter<A>
impl<A> UnsafeUnpin for IntoIter<A>
impl<A> UnwindSafe for IntoIter<A>
impl<A: Array + Clone> Clone for IntoIter<A>
fn clone(self: &Self) -> IntoIter<A>
impl<A: Array> Debug for IntoIter<A>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<A: Array> DoubleEndedIterator for IntoIter<A>
fn next_back(self: &mut Self) -> Option<<A as >::Item>
impl<A: Array> Drop for IntoIter<A>
fn drop(self: &mut Self)
impl<A: Array> ExactSizeIterator for IntoIter<A>
impl<A: Array> FusedIterator for IntoIter<A>
impl<A: Array> Iterator for IntoIter<A>
fn next(self: &mut Self) -> Option<<A as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<I> IntoIterator for IntoIter<A>
fn into_iter(self: Self) -> I
impl<T> Any for IntoIter<A>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for IntoIter<A>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for IntoIter<A>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> CloneToUninit for IntoIter<A>
unsafe fn clone_to_uninit(self: &Self, dest: *mut u8)
impl<T> From for IntoIter<A>
fn from(t: T) -> TReturns the argument unchanged.
impl<T> ToOwned for IntoIter<A>
fn to_owned(self: &Self) -> Tfn clone_into(self: &Self, target: &mut T)
impl<T, U> Into for IntoIter<A>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for IntoIter<A>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for IntoIter<A>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>