Struct Drain
struct Drain<'a, T: 'a + Array> { ... }
An iterator that removes the items from a SmallVec and yields them by value.
Returned from SmallVec::drain.
Implementations
impl<'a, T> Freeze for Drain<'a, T>
impl<'a, T> RefUnwindSafe for Drain<'a, T>
impl<'a, T> Unpin for Drain<'a, T>
impl<'a, T> UnsafeUnpin for Drain<'a, T>
impl<'a, T> UnwindSafe for Drain<'a, T>
impl<'a, T: 'a + Array> Debug for Drain<'a, T>
fn fmt(self: &Self, f: &mut Formatter<'_>) -> Result
impl<'a, T: 'a + Array> DoubleEndedIterator for Drain<'a, T>
fn next_back(self: &mut Self) -> Option<<T as >::Item>
impl<'a, T: 'a + Array> Drop for Drain<'a, T>
fn drop(self: &mut Self)
impl<'a, T: 'a + Array> Iterator for Drain<'a, T>
fn next(self: &mut Self) -> Option<<T as >::Item>fn size_hint(self: &Self) -> (usize, Option<usize>)
impl<'a, T: Array> ExactSizeIterator for Drain<'a, T>
fn len(self: &Self) -> usize
impl<'a, T: Array> FusedIterator for Drain<'a, T>
impl<'a, T: Send + Array> Send for Drain<'a, T>
impl<'a, T: Sync + Array> Sync for Drain<'a, T>
impl<I> IntoIterator for Drain<'a, T>
fn into_iter(self: Self) -> I
impl<T> Any for Drain<'a, T>
fn type_id(self: &Self) -> TypeId
impl<T> Borrow for Drain<'a, T>
fn borrow(self: &Self) -> &T
impl<T> BorrowMut for Drain<'a, T>
fn borrow_mut(self: &mut Self) -> &mut T
impl<T> From for Drain<'a, T>
fn from(t: T) -> TReturns the argument unchanged.
impl<T, U> Into for Drain<'a, T>
fn into(self: Self) -> UCalls
U::from(self).That is, this conversion is whatever the implementation of
[From]<T> for Uchooses to do.
impl<T, U> TryFrom for Drain<'a, T>
fn try_from(value: U) -> Result<T, <T as TryFrom<U>>::Error>
impl<T, U> TryInto for Drain<'a, T>
fn try_into(self: Self) -> Result<U, <U as TryFrom<T>>::Error>