Trait Array

unsafe trait Array

Types that can be used as the backing store for a SmallVec.

Associated Types

type Item

The type of the array's elements.

Required Methods

fn size() -> usize

Returns the number of items the array can hold.

Implementors