Trait Array
unsafe trait Array
Types that can be used as the backing store for a SmallVec.
Associated Types
type ItemThe type of the array's elements.
Required Methods
fn size() -> usizeReturns the number of items the array can hold.
Implementors
impl<T, N: usize> Array for [T; N]